==> ohdear_integration-1.0.1.tar.gz: ohdear_integration/src/Commands/OhDearIntegrationCommands.php <==
<?php

namespace Drupal\ohdear_integration\Commands;

use Consolidation\OutputFormatters\StructuredData\RowsOfFields;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\State\StateInterface;
use Drupal\ohdear_integration\OhDearSdkService;
use Drupal\shs\StringTranslationTrait;
use Drush\Commands\DrushCommands;

/**
 * A Drush command file.
 */
class OhDearIntegrationCommands extends DrushCommands {

  use StringTranslationTrait;

  /**
   * OhDear sdk service.
   *
   * @var \Drupal\ohdear_integration\OhDearSdkService
   */
  protected $ohDear;

  /**
   * Configuration of OhDear integration settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $ohDearIntegrationSettings;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Constructs a OhDear Integration commands object.
   *
   * @param \Drupal\ohdear_integration\OhDearSdkService $ohdear_sdk_service
   *   The ohdear integration sdk service.
   * @param \Drupal\Core\Config\ImmutableConfig $ohdear_integration_settings
   *   OhDear Integration settings.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(OhDearSdkService $ohdear_sdk_service, ImmutableConfig $ohdear_integration_settings, StateInterface $state) {
    parent::__construct();
    $this->ohDear = $ohdear_sdk_service;
    $this->ohDearIntegrationSettings = $ohdear_integration_settings;
    $this->state = $state;
  }

  /**
   * Prints the current maintenance status or starts/stops maintenance.
   *
   * @param array $options
   *   An associative array of options.
   *
   * @option start
   *   Starts the maintenance window in OhDear app.
   * @option stop
   *   Stops the maintenance window in OhDear app.
   * @option with-drupal
   *   Puts drupal in or out of maintenance mode.
   * @option time-length
   *   Time length for the maintenance period in seconds (default: 1 hour).
   * @option number
   *   Number of maintenance windows to show (default: 5).
   * @usage ohdear-maintenance
   *   Prints last 5 maintenance periods.
   *
   * @command ohdear:maintenance
   * @aliases ohdear-maintenance
   * @field-labels
   *   id: Id
   *   site_id: Site Id
   *   starts_at: Starts at
   *   ends_at: Ends at
   * @default-fields id,site_id,starts_at,ends_at
   *
   * @return \Consolidation\OutputFormatters\StructuredData\RowsOfFields
   *   A list of OhDear maintenance windows or activity description.
   */
  public function maintenance(array $options = [
    'start' => NULL,
    'stop' => NULL,
    'with-drupal' => NULL,
    'time-length' => 3600,
    'number' => 5,
  ]) {
    $ohDear = $this->ohDear->getOhDear();
    $siteId = $this->ohDear->getSiteId();
    $site = $ohDear->site($siteId);
    // @see https://ohdear.app/docs/integrations/the-oh-dear-php-sdk#maintenance-windows
    if (!$options['start'] && !$options['stop']) {
      // Just print out current maintenance window status.
      $maintenanceWindows = $this->getMaintenancePeriods($siteId, $options['number']);
      return new RowsOfFields($maintenanceWindows);
    }
    elseif ($options['start'] && $options['stop']) {
      $this->logger->warning('Only one of --start or --stop flags can be used.');
      $maintenanceWindows = $this->getMaintenancePeriods($siteId, $options['number']);
      return new RowsOfFields($maintenanceWindows);
    }
    elseif ($options['start']) {
      $time_length = $options['time-length'] ?? 3600;
      $maintenance_window = $ohDear->startSiteMaintenance($siteId, $time_length);
      if ($options['with-drupal']) {
        $this->state->set('system.maintenance_mode', 1);
      }
      $this->output()->writeln($this->t('Maintenance period @id started for @site. It ends at @date.', [
        '@id' => $maintenance_window->id,
        '@site' => $site->url,
        '@date' => $maintenance_window->endsAt ?? '',
      ]));
      return NULL;
    }
    elseif ($options['stop']) {
      $ohDear->stopSiteMaintenance($siteId);
      if ($options['with-drupal']) {
        $this->state->set('system.maintenance_mode', 0);
      }
      $this->output()->writeln($this->t('Maintenance period stopped for @site.', [
        '@site' => $site->url,
      ]));
      return NULL;
    }

    $this->logger->error('Something went wrong. No condition was met.');
    return NULL;
  }

  /**
   * Gets maintenance period for specific site.
   *
   * @param int|null $siteId
   *   Site id.
   * @param int $num
   *   Number of maintenance windows.
   *
   * @return array
   *   Array of last maintenance periods.
   *
   * @throws \Exception
   */
  protected function getMaintenancePeriods(?int $siteId = NULL, int $num = 5) {
    if (!$siteId) {
      $siteId = $this->ohDear->getSiteId();
    }
    $ohDear = $this->ohDear->getOhDear();
    $maintenanceWindows = array_slice(array_reverse($ohDear->maintenancePeriods($siteId)), 0, $num, TRUE);
    if (empty($maintenanceWindows)) {
      $this->logger->warning('No maintence window found.');
    }
    $rows = [];
    foreach ($maintenanceWindows as $window) {
      // @todo Add a check if a maintenance is currently active.
      $rows[] = [
        'id' => $window->id,
        'site_id' => $window->siteId,
        'starts_at' => $window->startsAt,
        'ends_at' => $window->endsAt ?? '',
      ];
    }
    return $rows;
  }

  /**
   * Prints current site id and url.
   *
   * @usage ohdear:info
   *
   * @command ohdear:info
   * @aliases ohdear-info
   * @field-labels
   *   id: Id
   *   type: Type
   *   label: Label
   *   enabled: Enabled
   *   latest_run_ended_at: Latest run ended at
   *   latest_run_result: Latest run result
   *   summary: Summary
   * @default-fields label,latest_run_ended_at,latest_run_result,summary,enabled
   *
   * @return \Consolidation\OutputFormatters\StructuredData\RowsOfFields
   *   A list of OhDear checks.
   */
  public function siteInfo(array $options = [
    'checks' => NULL,
  ]) {
    $ohDear = $this->ohDear->getOhDear();
    $siteId = $this->ohDear->getSiteId();
    $site = $ohDear->site($siteId);
    $this->output()->writeln($this->t('Site ID: @id, Url: @url', [
      '@id' => (string) $site->id,
      '@url' => $site->url,
    ]));
    $this->output()->writeln($this->t('Summarized check results: @results (@date).', [
      '@results' => $site->attributes['summarized_check_result'] ?? 'unknown',
      '@date' => $site->attributes['latest_run_date'] ?? '',
    ]));
    if (isset($options['checks'])) {
      $checks = [];
      foreach ($site->attributes['checks'] as $check) {
        $check['enabled'] = $check['enabled'] ? 'On' : 'Off';
        $checks[] = $check;
      }
      return new RowsOfFields($checks);
    }
    return NULL;
  }

}

==> ohdear_integration-1.0.5.tar.gz: ohdear_integration/src/Commands/OhDearIntegrationCommands.php <==
<?php

namespace Drupal\ohdear_integration\Commands;

use Consolidation\OutputFormatters\StructuredData\RowsOfFields;
use Drupal\Core\Config\ImmutableConfig;
use Drupal\Core\State\StateInterface;
use Drupal\ohdear_integration\OhDearSdkService;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drush\Commands\DrushCommands;

/**
 * A Drush command file.
 */
class OhDearIntegrationCommands extends DrushCommands {

  use StringTranslationTrait;

  /**
   * OhDear sdk service.
   *
   * @var \Drupal\ohdear_integration\OhDearSdkService
   */
  protected $ohDear;

  /**
   * Configuration of OhDear integration settings.
   *
   * @var \Drupal\Core\Config\ImmutableConfig
   */
  protected $ohDearIntegrationSettings;

  /**
   * The state service.
   *
   * @var \Drupal\Core\State\StateInterface
   */
  protected $state;

  /**
   * Constructs a OhDear Integration commands object.
   *
   * @param \Drupal\ohdear_integration\OhDearSdkService $ohdear_sdk_service
   *   The ohdear integration sdk service.
   * @param \Drupal\Core\Config\ImmutableConfig $ohdear_integration_settings
   *   OhDear Integration settings.
   * @param \Drupal\Core\State\StateInterface $state
   *   The state service.
   */
  public function __construct(OhDearSdkService $ohdear_sdk_service, ImmutableConfig $ohdear_integration_settings, StateInterface $state) {
    parent::__construct();
    $this->ohDear = $ohdear_sdk_service;
    $this->ohDearIntegrationSettings = $ohdear_integration_settings;
    $this->state = $state;
  }

  /**
   * Prints the current maintenance status or starts/stops maintenance.
   *
   * @param array $options
   *   An associative array of options.
   *
   * @option start
   *   Starts the maintenance window in OhDear app.
   * @option stop
   *   Stops the maintenance window in OhDear app.
   * @option with-drupal
   *   Puts drupal in or out of maintenance mode.
   * @option time-length
   *   Time length for the maintenance period in seconds (default: 1 hour).
   * @option number
   *   Number of maintenance windows to show (default: 5).
   * @usage ohdear-maintenance
   *   Prints last 5 maintenance periods.
   *
   * @command ohdear:maintenance
   * @aliases ohdear-maintenance
   * @field-labels
   *   id: Id
   *   site_id: Site Id
   *   starts_at: Starts at
   *   ends_at: Ends at
   * @default-fields id,site_id,starts_at,ends_at
   *
   * @return \Consolidation\OutputFormatters\StructuredData\RowsOfFields
   *   A list of OhDear maintenance windows or activity description.
   */
  public function maintenance(array $options = [
    'start' => NULL,
    'stop' => NULL,
    'with-drupal' => NULL,
    'time-length' => 3600,
    'number' => 5,
  ]) {
    $ohDear = $this->ohDear->getOhDear();
    $siteId = $this->ohDear->getSiteId();
    $site = $ohDear->site($siteId);
    // @see https://ohdear.app/docs/integrations/the-oh-dear-php-sdk#maintenance-windows
    if (!$options['start'] && !$options['stop']) {
      // Just print out current maintenance window status.
      $maintenanceWindows = $this->getMaintenancePeriods($siteId, $options['number']);
      return new RowsOfFields($maintenanceWindows);
    }
    elseif ($options['start'] && $options['stop']) {
      $this->logger->warning('Only one of --start or --stop flags can be used.');
      $maintenanceWindows = $this->getMaintenancePeriods($siteId, $options['number']);
      return new RowsOfFields($maintenanceWindows);
    }
    elseif ($options['start']) {
      $time_length = $options['time-length'] ?? 3600;
      $maintenance_window = $ohDear->startSiteMaintenance($siteId, $time_length);
      if ($options['with-drupal']) {
        $this->state->set('system.maintenance_mode', 1);
      }
      $this->output()->writeln($this->t('Maintenance period @id started for @site. It ends at @date.', [
        '@id' => $maintenance_window->id,
        '@site' => $site->url,
        '@date' => $maintenance_window->endsAt ?? '',
      ]));
      return NULL;
    }
    elseif ($options['stop']) {
      $ohDear->stopSiteMaintenance($siteId);
      if ($options['with-drupal']) {
        $this->state->set('system.maintenance_mode', 0);
      }
      $this->output()->writeln($this->t('Maintenance period stopped for @site.', [
        '@site' => $site->url,
      ]));
      return NULL;
    }

    $this->logger->error('Something went wrong. No condition was met.');
    return NULL;
  }

  /**
   * Gets maintenance period for specific site.
   *
   * @param int|null $siteId
   *   Site id.
   * @param int $num
   *   Number of maintenance windows.
   *
   * @return array
   *   Array of last maintenance periods.
   *
   * @throws \Exception
   */
  protected function getMaintenancePeriods(?int $siteId = NULL, int $num = 5) {
    if (!$siteId) {
      $siteId = $this->ohDear->getSiteId();
    }
    $ohDear = $this->ohDear->getOhDear();
    $maintenanceWindows = array_slice(array_reverse($ohDear->maintenancePeriods($siteId)), 0, $num, TRUE);
    if (empty($maintenanceWindows)) {
      $this->logger->warning('No maintence window found.');
    }
    $rows = [];
    foreach ($maintenanceWindows as $window) {
      // @todo Add a check if a maintenance is currently active.
      $rows[] = [
        'id' => $window->id,
        'site_id' => $window->siteId,
        'starts_at' => $window->startsAt,
        'ends_at' => $window->endsAt ?? '',
      ];
    }
    return $rows;
  }

  /**
   * Prints current site id and url.
   *
   * @usage ohdear:info
   *
   * @command ohdear:info
   * @aliases ohdear-info
   * @field-labels
   *   id: Id
   *   type: Type
   *   label: Label
   *   enabled: Enabled
   *   latest_run_ended_at: Latest run ended at
   *   latest_run_result: Latest run result
   *   summary: Summary
   * @default-fields label,latest_run_ended_at,latest_run_result,summary,enabled
   *
   * @return \Consolidation\OutputFormatters\StructuredData\RowsOfFields
   *   A list of OhDear checks.
   */
  public function siteInfo(array $options = [
    'checks' => NULL,
  ]) {
    $ohDear = $this->ohDear->getOhDear();
    $siteId = $this->ohDear->getSiteId();
    $site = $ohDear->site($siteId);
    $this->output()->writeln($this->t('Site ID: @id, Url: @url', [
      '@id' => (string) $site->id,
      '@url' => $site->url,
    ]));
    $this->output()->writeln($this->t('Summarized check results: @results (@date).', [
      '@results' => $site->attributes['summarized_check_result'] ?? 'unknown',
      '@date' => $site->attributes['latest_run_date'] ?? '',
    ]));
    if (isset($options['checks'])) {
      $checks = [];
      foreach ($site->attributes['checks'] as $check) {
        $check['enabled'] = $check['enabled'] ? 'On' : 'Off';
        $checks[] = $check;
      }
      return new RowsOfFields($checks);
    }
    return NULL;
  }

}
